==> haskell-split-0.2.3.4-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 split
version:              0.2.3.4
visibility:           public
id:                   split-0.2.3.4-78667o0ZlnR14Dks6mNAzP
key:                  split-0.2.3.4-78667o0ZlnR14Dks6mNAzP
license:              BSD-3-Clause
copyright:            (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer:           byorgey@gmail.com
author:               Brent Yorgey
stability:            stable
synopsis:             Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:

    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).

    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.

    To get started, see the "Data.List.Split" module.

category:             List
abi:                  0a3cb615f3064af5ab43acc0a9f6a46a
exposed:              True
exposed-modules:      Data.List.Split Data.List.Split.Internals
import-dirs:          /usr/lib/ghc-8.10.1/site-local/split-0.2.3.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/split-0.2.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/split-0.2.3.4
hs-libraries:         HSsplit-0.2.3.4-78667o0ZlnR14Dks6mNAzP
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-split/html/split.haddock
haddock-html:         /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-split-0.2.3.4-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-split.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 split
version:              0.2.3.4
visibility:           public
id:                   split-0.2.3.4-1yMQ9B3t34pK1eil56apCV
key:                  split-0.2.3.4-1yMQ9B3t34pK1eil56apCV
license:              BSD-3-Clause
copyright:            (c) Brent Yorgey, Louis Wasserman 2008-2012
maintainer:           byorgey@gmail.com
author:               Brent Yorgey
stability:            stable
synopsis:             Combinator library for splitting lists.
description:
    A collection of various methods for splitting
    lists into parts, akin to the \"split\" function
    found in several mainstream languages. Here is
    its tale:

    Once upon a time the standard "Data.List" module
    held no function for splitting a list into parts
    according to a delimiter.  Many a brave
    lambda-knight strove to add such a function, but
    their striving was in vain, for Lo, the Supreme
    Council fell to bickering amongst themselves what
    was to be the essential nature of the One True
    Function which could cleave a list in twain (or
    thrain, or any required number of parts).

    And thus came to pass the split package,
    comprising divers functions for splitting a list
    asunder, each according to its nature.  And the
    Supreme Council had no longer any grounds for
    argument, for the favored method of each was
    contained therein.

    To get started, see the "Data.List.Split" module.

category:             List
abi:                  188e92b39a270ab99e0677cc7a392fc6
exposed:              True
exposed-modules:      Data.List.Split Data.List.Split.Internals
import-dirs:          /usr/lib/ghc-8.10.1/site-local/split-0.2.3.4
library-dirs:         /usr/lib/ghc-8.10.1/site-local/split-0.2.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/split-0.2.3.4
hs-libraries:         HSsplit-0.2.3.4-1yMQ9B3t34pK1eil56apCV
depends:              base-4.14.0.0
haddock-interfaces:   /usr/share/doc/haskell-split/html/split.haddock
haddock-html:         /usr/share/doc/haskell-split/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
